require 'mina/bundler'
require 'mina/rails'
require 'mina/git'
# require 'mina/rbenv'  # for rbenv support. (http://rbenv.org)
# require 'mina/rvm'    # for rvm support. (http://rvm.io)

# Basic settings:
#   domain       - The hostname to SSH to.
#   deploy_to    - Path to deploy into.
#   repository   - Git repo to clone from. (needed by mina/git)
#   branch       - Branch name to deploy. (needed by mina/git)

set :domain, 'samfundet.no'
set :user, ENV['USER'] unless ENV['USER'].nil?
set :repository, 'git@github.com:Samfundet/Samfundet3.git'
set :branch, ENV['BRANCH'].to_s == '' && 'master' || ENV['BRANCH']

# Manually create these paths in shared/ (eg: shared/config/database.yml) in your server.
# They will be linked in the 'deploy:link_shared_paths' step.


# Optional settings:
#   set :port, '30000'     # SSH port number.

# This task is the environment that is loaded for most commands, such as
# `mina deploy` or `mina rake`.

namespace :environment do
  desc 'Set up staging-specific variables'
  task :staging do set :rails_env, 'staging'
    set :user, 'samfundet-web-deploy'
    set :shared_paths, ['config/database.yml', 'log']
    set :deploy_to, '/var/www/samfundet.no/www-beta'

    set :gem_path, "#{deploy_to}/shared/bundle/ruby/1.9.1"
    set :gem_home, "#{deploy_to}/shared/bundle/ruby/1.9.1"
    set :gem_bin, "#{deploy_to}/shared/bundle/ruby/1.9.1/bin"

    queue %{export GEM_PATH=#{gem_path}}
    queue %{export GEM_HOME=#{gem_home}}
    queue %{PATH="$PATH:#{gem_bin}"}
  end

  desc 'Set up production-specific variables'
  task :production do set :rails_env, 'production'
    set :deploy_to, '/var/www/samfundet.no/www-rails/samfundet'

    set :gem_path, "#{deploy_to}/vendor/ruby/1.9.1"
    set :gem_home, "#{deploy_to}/vendor/ruby/1.9.1"
    set :gem_bin, "#{deploy_to}/vendor/ruby/1.9.1/bin"

    queue %{export GEM_PATH=#{gem_path}}
    queue %{export GEM_HOME=#{gem_home}}
    queue %{PATH="$PATH:#{gem_bin}"}

    queue %{umask 002}
  end
end

# task :environment do
  # If you're using rbenv, use this to load the rbenv environment.
  # Be sure to commit your .rbenv-version to your repository.
  # invoke :'rbenv:load'

  # For those using RVM, use this to load an RVM version@gemset.
  # invoke :'rvm:use[ruby-1.9.3-p125@default]'
# end

# Put any custom mkdir's in here for when `mina setup` is ran.
# For Rails apps, we'll make some of the shared paths that are shared between
# all releases.
namespace :setup do
  task :staging => :'environment:staging' do
    queue! %[mkdir -p "#{deploy_to}/shared/log"]
    queue! %[chmod g+rx,u+rwx "#{deploy_to}/shared/log"]

    queue! %[mkdir -p "#{deploy_to}/shared/config"]
    queue! %[chmod g+rx,u+rwx "#{deploy_to}/shared/config"]

    queue! %[touch "#{deploy_to}/shared/config/database.yml"]
    queue  %[echo "-----> Be sure to edit 'shared/config/database.yml'."]
  end
end

namespace :deploy do
  desc "Deploy staging environment."
  task :staging => :'environment:staging' do
    deploy do
      invoke :'git:clone'
      invoke :'deploy:link_shared_paths'
      invoke :'bundle:install'
      invoke :'rails:db_migrate'
      invoke :'rails:assets_precompile'

      invoke :'passenger:restart'
    end
  end

  desc "Deploy production environment."
  task :production => :'environment:production' do
    in_directory deploy_to do
      queue 'git checkout master'
      queue 'git fetch'
      queue 'git reset --hard origin/' + branch

      queue 'bundle install --path vendor/'
      queue 'bundle exec rake db:migrate RAILS_ENV=production'

      if ENV['SKIP_ASSETS'].nil?
        queue 'bundle exec rake assets:precompile'
      end

      queue 'touch tmp/restart.txt'

      invoke :'memcache:flush'
    end
  end
end

namespace :memcache do
  desc "Flush memcache"
  task :flush => :'environment:production' do
    queue %{sg lim-web 'echo "flush_all" | nc localhost 11211'}
  end
end

namespace :passenger do
  desc "Restart Passenger"
  task :restart => :'environment:staging' do
    in_directory "#{deploy_to}/current" do
      queue! "test -d 'tmp' || mkdir tmp"
      queue! "touch tmp/restart.txt"
    end
  end
end

# For help in making your deploy script, see the Mina documentation:
#
#  - http://nadarei.co/mina
#  - http://nadarei.co/mina/tasks
#  - http://nadarei.co/mina/settings
#  - http://nadarei.co/mina/helpers

